<?php
/**
 * VW Yoga Fitness Theme Customizer
 *
 * @package VW Yoga Fitness
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_yoga_fitness_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_yoga_fitness_custom_controls' );

function vw_yoga_fitness_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_yoga_fitness_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-yoga-fitness' ),
	    'description' => __( 'Description of what this panel does.', 'vw-yoga-fitness' ),
	) );

	$wp_customize->add_section( 'vw_yoga_fitness_left_right', array(
    	'title'      => __( 'General Settings', 'vw-yoga-fitness' ),
		'priority'   => 30,
		'panel' => 'vw_yoga_fitness_panel_id'
	) );

	$wp_customize->add_setting('vw_yoga_fitness_width_option',array(
        'default' => __('Full Width','vw-yoga-fitness'),
        'sanitize_callback' => 'vw_yoga_fitness_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Yoga_Fitness_Image_Radio_Control($wp_customize, 'vw_yoga_fitness_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-yoga-fitness'),
        'description' => __('Here you can change the width layout of Website.','vw-yoga-fitness'),
        'section' => 'vw_yoga_fitness_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_yoga_fitness_theme_options',array(
        'default' => __('Right Sidebar','vw-yoga-fitness'),
        'sanitize_callback' => 'vw_yoga_fitness_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_yoga_fitness_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-yoga-fitness'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-yoga-fitness'),
        'section' => 'vw_yoga_fitness_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-yoga-fitness'),
            'Right Sidebar' => __('Right Sidebar','vw-yoga-fitness'),
            'One Column' => __('One Column','vw-yoga-fitness'),
            'Three Columns' => __('Three Columns','vw-yoga-fitness'),
            'Four Columns' => __('Four Columns','vw-yoga-fitness'),
            'Grid Layout' => __('Grid Layout','vw-yoga-fitness')
        ),
	));

	$wp_customize->add_setting('vw_yoga_fitness_page_layout',array(
        'default' => __('One Column','vw-yoga-fitness'),
        'sanitize_callback' => 'vw_yoga_fitness_sanitize_choices'
	));
	$wp_customize->add_control('vw_yoga_fitness_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-yoga-fitness'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-yoga-fitness'),
        'section' => 'vw_yoga_fitness_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-yoga-fitness'),
            'Right Sidebar' => __('Right Sidebar','vw-yoga-fitness'),
            'One Column' => __('One Column','vw-yoga-fitness')
        ),
	) );

	//Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_yoga_fitness_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','vw-yoga-fitness' ),
		'section' => 'vw_yoga_fitness_left_right'
    )));

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_yoga_fitness_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','vw-yoga-fitness' ),
		'section' => 'vw_yoga_fitness_left_right'
    )));

	//Pre-Loader
	$wp_customize->add_setting( 'vw_yoga_fitness_loader_enable',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','vw-yoga-fitness' ),
        'section' => 'vw_yoga_fitness_left_right'
    )));

	$wp_customize->add_setting('vw_yoga_fitness_loader_icon',array(
        'default' => __('Two Way','vw-yoga-fitness'),
        'sanitize_callback' => 'vw_yoga_fitness_sanitize_choices'
	));
	$wp_customize->add_control('vw_yoga_fitness_loader_icon',array(
        'type' => 'select',
        'label' => __('Pre-Loader Type','vw-yoga-fitness'),
        'section' => 'vw_yoga_fitness_left_right',
        'choices' => array(
            'Two Way' => __('Two Way','vw-yoga-fitness'),
            'Dots' => __('Dots','vw-yoga-fitness'),
            'Rotate' => __('Rotate','vw-yoga-fitness')
        ),
	) );

	//Topbar
	$wp_customize->add_section( 'vw_yoga_fitness_topbar', array(
    	'title'      => __( 'Topbar Settings', 'vw-yoga-fitness' ),
		'priority'   => 30,
		'panel' => 'vw_yoga_fitness_panel_id'
	) );

	//Sticky Header
	$wp_customize->add_setting( 'vw_yoga_fitness_sticky_header',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','vw-yoga-fitness' ),
        'section' => 'vw_yoga_fitness_topbar'
    )));

	$wp_customize->add_setting( 'vw_yoga_fitness_search_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_search_hide_show',array(
		'label' => esc_html__( 'Show / Hide Search','vw-yoga-fitness' ),
		'section' => 'vw_yoga_fitness_topbar'
    )));

	$wp_customize->add_setting('vw_yoga_fitness_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_yoga_fitness_button_text',array(
		'label'	=> __('Add Button Text','vw-yoga-fitness'),
		'input_attrs' => array(
            'placeholder' => __( 'Book Now', 'vw-yoga-fitness' ),
        ),
		'section'=> 'vw_yoga_fitness_topbar',
		'type'=> 'text'
	));		

	$wp_customize->add_setting('vw_yoga_fitness_button_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('vw_yoga_fitness_button_url',array(
		'label'	=> __('Add Button URL','vw-yoga-fitness'),
		'input_attrs' => array(
            'placeholder' => __( 'www.example.com', 'vw-yoga-fitness' ),
        ),
		'section'=> 'vw_yoga_fitness_topbar',
		'type'=> 'url'
	));	
    
	//Slider
	$wp_customize->add_section( 'vw_yoga_fitness_slidersettings' , array(
    	'title'      => __( 'Slider Section', 'vw-yoga-fitness' ),
		'priority'   => null,
		'panel' => 'vw_yoga_fitness_panel_id'
	) );

	$wp_customize->add_setting( 'vw_yoga_fitness_slider_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_slider_hide_show',array(
		'label' => esc_html__( 'Show / Hide Slider','vw-yoga-fitness' ),
		'section' => 'vw_yoga_fitness_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'vw_yoga_fitness_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_yoga_fitness_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_yoga_fitness_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'vw-yoga-fitness' ),
			'description' => __('Slider image size (1500 x 590)','vw-yoga-fitness'),
			'section'  => 'vw_yoga_fitness_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('vw_yoga_fitness_slider_content_option',array(
        'default' => __('Left','vw-yoga-fitness'),
        'sanitize_callback' => 'vw_yoga_fitness_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Yoga_Fitness_Image_Radio_Control($wp_customize, 'vw_yoga_fitness_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-yoga-fitness'),
        'section' => 'vw_yoga_fitness_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_yoga_fitness_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_yoga_fitness_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-yoga-fitness' ),
		'section'     => 'vw_yoga_fitness_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_yoga_fitness_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_yoga_fitness_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_yoga_fitness_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_yoga_fitness_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-yoga-fitness' ),
	'section'     => 'vw_yoga_fitness_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_yoga_fitness_slider_opacity_color',
	'choices' => array(
		'0' =>  esc_attr('0','vw-yoga-fitness'),
		'0.1' =>  esc_attr('0.1','vw-yoga-fitness'),
		'0.2' =>  esc_attr('0.2','vw-yoga-fitness'),
		'0.3' =>  esc_attr('0.3','vw-yoga-fitness'),
		'0.4' =>  esc_attr('0.4','vw-yoga-fitness'),
		'0.5' =>  esc_attr('0.5','vw-yoga-fitness'),
		'0.6' =>  esc_attr('0.6','vw-yoga-fitness'),
		'0.7' =>  esc_attr('0.7','vw-yoga-fitness'),
		'0.8' =>  esc_attr('0.8','vw-yoga-fitness'),
		'0.9' =>  esc_attr('0.9','vw-yoga-fitness')
	),
	));

	//Services
	$wp_customize->add_section( 'vw_yoga_fitness_service_section' , array(
    	'title'      => __( 'Our Classes Section', 'vw-yoga-fitness' ),
		'priority'   => null,
		'panel' => 'vw_yoga_fitness_panel_id'
	) );

	$wp_customize->add_setting('vw_yoga_fitness_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_yoga_fitness_section_title',array(
		'label'	=> __('Section Title','vw-yoga-fitness'),
		'input_attrs' => array(
            'placeholder' => __( 'Our Classes', 'vw-yoga-fitness' ),
        ),
		'section'=> 'vw_yoga_fitness_service_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_yoga_fitness_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_yoga_fitness_section_text',array(
		'label'	=> __('Section Text','vw-yoga-fitness'),
		'input_attrs' => array(
            'placeholder' => __( 'Lorem ipsum is a dummy text.', 'vw-yoga-fitness' ),
        ),
		'section'=> 'vw_yoga_fitness_service_section',
		'type'=> 'text'
	));	

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_yoga_fitness_services',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_yoga_fitness_sanitize_choices',
	));
	$wp_customize->add_control('vw_yoga_fitness_services',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display services','vw-yoga-fitness'),
		'description' => __('Image Size (340 x 255)','vw-yoga-fitness'),
		'section' => 'vw_yoga_fitness_service_section',
	));

	//Classes excerpt
	$wp_customize->add_setting( 'vw_yoga_fitness_classes_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_yoga_fitness_classes_excerpt_number', array(
		'label'       => esc_html__( 'Classes Excerpt length','vw-yoga-fitness' ),
		'section'     => 'vw_yoga_fitness_service_section',
		'type'        => 'range',
		'settings'    => 'vw_yoga_fitness_classes_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_yoga_fitness_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-yoga-fitness'),
		'panel' => 'vw_yoga_fitness_panel_id',
	));	

	$wp_customize->add_setting( 'vw_yoga_fitness_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-yoga-fitness' ),
        'section' => 'vw_yoga_fitness_blog_post'
    )));

    $wp_customize->add_setting( 'vw_yoga_fitness_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_toggle_author',array(
		'label' => esc_html__( 'Author','vw-yoga-fitness' ),
		'section' => 'vw_yoga_fitness_blog_post'
    )));

    $wp_customize->add_setting( 'vw_yoga_fitness_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-yoga-fitness' ),
		'section' => 'vw_yoga_fitness_blog_post'
    )));

    $wp_customize->add_setting( 'vw_yoga_fitness_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_yoga_fitness_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-yoga-fitness' ),
		'section'     => 'vw_yoga_fitness_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_yoga_fitness_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog layout
    $wp_customize->add_setting('vw_yoga_fitness_blog_layout_option',array(
        'default' => __('Default','vw-yoga-fitness'),
        'sanitize_callback' => 'vw_yoga_fitness_sanitize_choices'
    ));
    $wp_customize->add_control(new VW_Yoga_Fitness_Image_Radio_Control($wp_customize, 'vw_yoga_fitness_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','vw-yoga-fitness'),
        'section' => 'vw_yoga_fitness_blog_post',
        'choices' => array(
            'Default' => get_template_directory_uri().'/assets/images/blog-layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/blog-layout2.png',
            'Left' => get_template_directory_uri().'/assets/images/blog-layout3.png',
    ))));

    //404 Page Setting
	$wp_customize->add_section('vw_yoga_fitness_404_page',array(
		'title'	=> __('404 Page Settings','vw-yoga-fitness'),
		'panel' => 'vw_yoga_fitness_panel_id',
	));	

	$wp_customize->add_setting('vw_yoga_fitness_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_yoga_fitness_404_page_title',array(
		'label'	=> __('Add Title','vw-yoga-fitness'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'vw-yoga-fitness' ),
        ),
		'section'=> 'vw_yoga_fitness_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_yoga_fitness_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_yoga_fitness_404_page_content',array(
		'label'	=> __('Add Text','vw-yoga-fitness'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'vw-yoga-fitness' ),
        ),
		'section'=> 'vw_yoga_fitness_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_yoga_fitness_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_yoga_fitness_404_page_button_text',array(
		'label'	=> __('Add Button Text','vw-yoga-fitness'),
		'input_attrs' => array(
            'placeholder' => __( 'Return to the home page', 'vw-yoga-fitness' ),
        ),
		'section'=> 'vw_yoga_fitness_404_page',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('vw_yoga_fitness_responsive_media',array(
		'title'	=> __('Responsive Media','vw-yoga-fitness'),
		'panel' => 'vw_yoga_fitness_panel_id',
	));

    $wp_customize->add_setting( 'vw_yoga_fitness_stickyheader_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_stickyheader_hide_show',array(
          'label' => esc_html__( 'Sticky Header','vw-yoga-fitness' ),
          'section' => 'vw_yoga_fitness_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_yoga_fitness_resp_slider_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_resp_slider_hide_show',array(
          'label' => esc_html__( 'Show / Hide Slider','vw-yoga-fitness' ),
          'section' => 'vw_yoga_fitness_responsive_media'
    )));

	$wp_customize->add_setting( 'vw_yoga_fitness_metabox_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_metabox_hide_show',array(
          'label' => esc_html__( 'Show / Hide Metabox','vw-yoga-fitness' ),
          'section' => 'vw_yoga_fitness_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_yoga_fitness_sidebar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_sidebar_hide_show',array(
          'label' => esc_html__( 'Show / Hide Sidebar','vw-yoga-fitness' ),
          'section' => 'vw_yoga_fitness_responsive_media'
    )));

	//Content Creation
	$wp_customize->add_section( 'vw_yoga_fitness_content_section' , array(
    	'title' => __( 'Customize Home Page', 'vw-yoga-fitness' ),
		'priority' => null,
		'panel' => 'vw_yoga_fitness_panel_id'
	) );

	$wp_customize->add_setting('vw_yoga_fitness_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Yoga_Fitness_Content_Creation( $wp_customize, 'vw_yoga_fitness_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-yoga-fitness' ),
		),
		'section' => 'vw_yoga_fitness_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-yoga-fitness' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('vw_yoga_fitness_footer',array(
		'title'	=> __('Footer','vw-yoga-fitness'),
		'panel' => 'vw_yoga_fitness_panel_id',
	));	
	
	$wp_customize->add_setting('vw_yoga_fitness_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_yoga_fitness_footer_text',array(
		'label'	=> __('Copyright Text','vw-yoga-fitness'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2018, .....', 'vw-yoga-fitness' ),
        ),
		'section'=> 'vw_yoga_fitness_footer',
		'type'=> 'text'
	));	

	$wp_customize->add_setting( 'vw_yoga_fitness_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_yoga_fitness_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Yoga_Fitness_Toggle_Switch_Custom_Control( $wp_customize, 'vw_yoga_fitness_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-yoga-fitness' ),
      	'section' => 'vw_yoga_fitness_footer'
    )));

	$wp_customize->add_setting('vw_yoga_fitness_scroll_top_alignment',array(
        'default' => __('Right','vw-yoga-fitness'),
        'sanitize_callback' => 'vw_yoga_fitness_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Yoga_Fitness_Image_Radio_Control($wp_customize, 'vw_yoga_fitness_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-yoga-fitness'),
        'section' => 'vw_yoga_fitness_footer',
        'settings' => 'vw_yoga_fitness_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'vw_yoga_fitness_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Yoga_Fitness_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Yoga_Fitness_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Yoga_Fitness_Customize_Section_Pro($manager,'example_1',array(
				'priority'   => 1,
				'title'    => esc_html__( 'VW Yoga Fitness', 'vw-yoga-fitness' ),
				'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-yoga-fitness' ),
				'pro_url'  => esc_url('https://www.vwthemes.com/themes/yoga-wordpress-theme/'),
			)));

		// Register sections.
		$manager->add_section(new VW_Yoga_Fitness_Customize_Section_Pro($manager,'example_2',array(
				'priority'   => 1,
				'title'    => esc_html__( 'DOCUMENTATION', 'vw-yoga-fitness' ),
				'pro_text' => esc_html__( 'DOCS', 'vw-yoga-fitness' ),
				'pro_url'  => admin_url('themes.php?page=vw_yoga_fitness_guide'),
			)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-yoga-fitness-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-yoga-fitness-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Yoga_Fitness_Customize::get_instance();